embassy-stm32

Crates

git

Versions

stm32l152cc

Flavors

TIM10

Struct TIM10 

pub struct TIM10 { /* private fields */ }
TIM10 peripheral

Implementations

Source

impl TIM10

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.